@@ -1,4 +1,5 @@
-/*
+/*      $Id: events.c,v 1.239 2004/08/22 22:18:50 olivier Exp $
+ 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
         the Free Software Foundation; either version 2, or (at your option)
@@ -904,7 +905,7 @@ handleDestroyNotify (DisplayInfo *display_info, XDestroyWindowEvent * ev)
     if (c)
     {
         TRACE ("DestroyNotify for \"%s\" (0x%lx)", c->name, c->window);
-        clientPassFocus (c->screen_info, c);
+        clientPassFocus (c->screen_info, c, c);
         clientUnframe (c, FALSE);
     }
 }
@@ -1008,7 +1009,7 @@ handleUnmapNotify (DisplayInfo *display_info, XUnmapEvent * ev)
         }
 
         screen_info = c->screen_info;
-        clientPassFocus (screen_info, c);
+        clientPassFocus (screen_info, c, c);
         
         /*
          * ICCCM spec states that a client wishing to switch
