@@ -1,4 +1,5 @@
-/*
+/*      $Id: stacking.c,v 1.18 2004/08/22 22:18:50 olivier Exp $
+ 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
         the Free Software Foundation; either version 2, or (at your option)
@@ -398,7 +399,7 @@ clientLower (Client * c)
     if (FLAG_TEST (c->flags, CLIENT_FLAG_MANAGED))
     {
         Client *client_sibling = NULL;
-
+        
         if (clientIsTransientOrModalForGroup (c))
         {
             client_sibling = clientGetTopMostForGroup (c);
@@ -434,7 +435,7 @@ clientLower (Client * c)
          */
         clientApplyStackList (screen_info);
         clientSetNetClientList (screen_info, net_client_list_stacking, screen_info->windows_stack);
-	clientPassFocus (screen_info, c);
+        clientPassFocus (screen_info, c, NULL);
         if (screen_info->last_raise == c)
         {
             screen_info->last_raise = NULL;
